@@ -4,21 +4,22 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '0.031';
+our $VERSION = '0.035';
 
 sub new(){
 	my $proto = shift;
 	my $class = ref($proto) || $proto;
 	my %params = @_;
 	my $self  = {};
-	$self->{start}	  = localtime;
-	$self->{user}	  = $params{user}   if( $params{user} );
-	$self->{target}  = $params{target} if( $params{target} );
-	$self->{control} = $params{control} if( $params{control} );
-	$self->{dcop}	  = "/usr/bin/dcop";
-	$self->{dcop} 	 .= " --user $self->{user} " if($self->{user});
-	$self->{dcop} 	 .= " $self->{target} " if($self->{target});
-	$self->{dcop} 	 .= " $self->{control} " if($self->{control});
+	$self->{start}		= localtime;
+	$self->{user}		= $params{user}   if( $params{user} );
+	$self->{target}		= $params{target} if( $params{target} );
+	$self->{control} 	= $params{control} if( $params{control} );
+	chomp( my $basepath = `kde-config --expandvars --exec-prefix` );
+	$self->{dcop}	 	= "$basepath/bin/dcop ";
+	$self->{dcop} 	 	.= "--user $self->{user} " if($self->{user});
+	$self->{dcop} 	 	.= "$self->{target} " if($self->{target});
+	$self->{dcop} 	 	.= "$self->{control} " if($self->{control});
 	bless( $self, $class );
 	return $self;
 }
